@@ -75,7 +75,8 @@ enum cli_var_type {
     cli_array_of_string, /* array of pointers to zero terminated strings */ 
     cli_any,     /* use the same type for column as stored in the database */
     cli_datetime, /* time in seconds since 00:00:00 UTC, January 1, 1970. */
-    cli_autoincrement, /* column od int4 type automatically assigned value during record insert */
+    cli_autoincrement, /* column of int4 type automatically assigned value during record insert */
+    cli_rectangle, 
     cli_unknown
 };
 
@@ -86,6 +87,12 @@ typedef signed int   cli_int4_t;
 typedef float        cli_real4_t;
 typedef double       cli_real8_t;
 
+#define CLI_RECTANGLE_DIMENSION 2
+typedef int          cli_coord_t;
+typedef struct { 
+    cli_coord_t  boundary[CLI_RECTANGLE_DIMENSION*2];
+} cli_rectangle_t;
+
 #ifndef __STDTP_H__
 #ifdef UNICODE
 typedef wchar_t char_t;
@@ -372,6 +379,22 @@ int GIGABASE_DLL_ENTRY cli_get_next(int statement);
  */
 int GIGABASE_DLL_ENTRY cli_get_prev(int statement);
 
+/*********************************************************************
+ * cli_kip
+ *     Skip specified number of rows. 
+ * Parameters:
+ *     statement  - statememt descriptor returned by cli_statement
+ *     n          - number of objects to be skipped
+ *                - if "n" is positive, then this function has the same effect as
+ *                     executing cli_get_next() function "n" times.
+ *                - if "n" is negative, then this function has the same effect as
+ *                     executing cli_get_prev() function "-n" times.
+ *                - if "n"  is zero, this method has no effect
+ * Returns:
+ *     result code as described in cli_result_code enum
+ */
+int GIGABASE_DLL_ENTRY cli_skip(int statement, int n);
+
 /*********************************************************************
  * cli_get_oid
  *     Get object identifier of the current record
